@@ -23,3 +23,9 @@ test_that("realtime_plot will throw an error when try to plot more than one stat
   skip_on_cran()
   expect_error(realtime_plot(c("08NM083","08MF005")))
 })
+
+test_that("throw an error when plotting a lake level station with Flow specified",{
+  l <- realtime_dd('08KH011')
+  expect_error(plot(l, Parameter = "Flow"))
+  expect_silent(plot(l, Parameter = "Level"))
+})
